==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>ファイルを上書きしますか?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>ファイル&apos;%1&apos;は既に存在します。上書きしますか？</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>ファイルのフォーマットバージョンは推奨されていません</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>使用しているファイルのフォーマットバージョンは推奨されていません：&apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>全ての黒いエンティティ及び画層は白色で保存されます。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>全てのカスタム色は最も近い固定色に変換されます。</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>続行しますか？</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>保存中...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>ファイルフォーマットバージョン&apos;%1&apos;で保存中です。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>黒いエンティティ及び画層は白色で保存されます。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>カスタム色は最も近い固定色に変換されます。</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>ファイル%1は保存されていません。</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saved drawing:</source>
        <translation>図面が保存されました：</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>フォーマット：</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;S 保存</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>ファイルを上書きしますか?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>ファイル&apos;%1&apos;は既に存在します。上書きしますか？</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>ファイルのフォーマットバージョンは推奨されていません</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>使用しているファイルのフォーマットバージョンは推奨されていません：&apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>全ての黒いエンティティ及び画層は白色で保存されます。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>全てのカスタム色は最も近い固定色に変換されます。</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>続行しますか？</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>保存中...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>ファイルフォーマットバージョン&apos;%1&apos;で保存中です。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>黒いエンティティ及び画層は白色で保存されます。</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>カスタム色は最も近い固定色に変換されます。</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>ファイル%1は保存されていません。</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Saved drawing:</source>
        <translation>図面が保存されました：</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>フォーマット：</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;S 保存</translation>
    </message>
</context>
</TS>
